/*
 * Copyright (c) 1997  Motoyuki Kasahara
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#ifndef EB_EB_H
#define EB_EB_H

#ifdef __cplusplus
extern "C" {
#endif

#ifdef EB_BUILD_LIBRARY
#include "types.h"
#else
#include <eb/types.h>
#endif


/*
 * Function declarations.
 */
#ifdef __STDC__

/* canonfile.c */
int eb_catalog_filename(EB_Book *);
int eb_appendix_catalog_filename(EB_Appendix *);
int eb_canonicalize_filename(char *);
void eb_fix_filename(EB_Book *, char *);
void eb_fix_appendix_filename(EB_Appendix *, char *);
/* havesearch.c */
int eb_have_exactword_search(EB_Book *);
int eb_have_word_search(EB_Book *);
int eb_have_endword_search(EB_Book *);
int eb_have_keyword_search(EB_Book *);
int eb_have_menu_search(EB_Book *);
int eb_have_multi_search(EB_Book *);
int eb_have_graphic_search(EB_Book *);
/* init.c */
void eb_initialize(EB_Book *);
int eb_bind(EB_Book *, const char *);
void eb_suspend(EB_Book *);
void eb_clear(EB_Book *);
int eb_initialize_messages(EB_Book *);
int eb_initialize_subbook(EB_Book *);
int eb_initialize_all_subbooks(EB_Book *);
/* jpcode.c */
void eb_jisx0208_to_euc(char *, const char *);
void eb_sjis_to_euc(char *, const char *);
/* match.c */
int eb_match_word(const char *, const char *, size_t);
int eb_match_exactword(const char *, const char *, size_t);
/* search.c */
void eb_initialize_search(void);
int eb_search_exactword(EB_Book *, EB_Hit *, const char *, int);
int eb_search_word(EB_Book *, EB_Hit *, const char *, int);
int eb_search_endword(EB_Book *, EB_Hit *, const char *, int);
int eb_search_keyword(EB_Book *, EB_Hit *, const char *, int);
int eb_search_menu(EB_Book *, EB_Position *);
int eb_next_exactword(EB_Book *, EB_Hit *, int);
int eb_next_word(EB_Book *, EB_Hit *, int);
int eb_next_endword(EB_Book *, EB_Hit *, int);
int eb_next_keyword(EB_Book *, EB_Hit *, int);
/* setword.c */
EB_Word_Code eb_set_word(EB_Book *, char *, char *, const char *);
EB_Word_Code eb_set_endword(EB_Book *, char *, char *, const char *);
/* subbook.c */
int eb_subbook_count(EB_Book *);
int eb_subbook_list(EB_Book *, EB_Subbook_Code *);
EB_Subbook_Code eb_subbook(EB_Book *);
const char *eb_subbook_title(EB_Book *);
const char *eb_subbook_title2(EB_Book *, EB_Subbook_Code);
const char *eb_subbook_directory(EB_Book *);
const char *eb_subbook_directory2(EB_Book *, EB_Subbook_Code);
int eb_set_subbook(EB_Book *, EB_Subbook_Code);
void eb_unset_subbook(EB_Book *);
/* util.c */
int eb_is_bound(EB_Book *);
const char *eb_path(EB_Book *);
EB_Disc_Code eb_disc_type(EB_Book *);
EB_Character_Code eb_character_code(EB_Book *);
/* text.c */
void eb_initialize_text(void);

#else /* not __STDC__ */

/* canonfile.c */
int eb_catalog_filename();
int eb_appendix_catalog_filename();
int eb_canonicalize_filename();
void eb_fix_filename();
void eb_fix_appendix_filename();
/* havesearch.c */
int eb_have_exactword_search();
int eb_have_word_search();
int eb_have_endword_search();
int eb_have_keyword_search();
int eb_have_menu_search();
int eb_have_multi_search();
int eb_have_graphic_search();
/* init.c */
void eb_initialize();
int eb_bind();
void eb_suspend();
void eb_clear();
int eb_initialize_messages();
int eb_initialize_subbook();
int eb_initialize_all_subbooks();
/* jpcode.c */
void eb_jisx0208_to_euc();
void eb_sjis_to_euc();
/* match.c */
int eb_match_word();
int eb_match_exactword();
/* search.c */
void eb_initialize_search();
int eb_search_exactword();
int eb_search_word();
int eb_search_endword();
int eb_search_keyword();
int eb_search_menu();
int eb_next_exactword();
int eb_next_word();
int eb_next_endword();
int eb_next_keyword();
/* setword.c */
EB_Word_Code eb_set_word();
EB_Word_Code eb_set_endword();
/* subbook.c */
int eb_subbook_count();
int eb_subbook_list();
EB_Subbook_Code eb_subbook();
const char *eb_subbook_title();
const char *eb_subbook_title2();
const char *eb_subbook_directory();
const char *eb_subbook_directory2();
int eb_set_subbook();
void eb_unset_subbook();
/* util.c */
int eb_is_bound();
const char *eb_path();
EB_Disc_Code eb_disc_type();
EB_Character_Code eb_character_code();
/* text.c */
void eb_initialize_text();

#endif /* not __STDC__ */


#ifdef __cplusplus
}
#endif

#endif /* not EB_EB_H */

