/*
 * Copyright (c) 1997  Motoyuki Kasahara
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#ifndef EB_IO_H
#define EB_IO_H

#ifdef __cplusplus
extern "C" {
#endif

#include <sys/types.h>

#ifdef EB_BUILD_LIBRARY
#include "types.h"
#else
#include <eb/types.h>
#endif


/*
 * CPP macro version of get_uint1(), get_uint2(), get_uint4().
 * If EB_UINT_FUNC is defined, use function version, instead.
 */
#ifndef EB_UINT_FUNC

#define eb_uint1(p) (*(const unsigned char *)(p))

#define eb_uint2(p) ((*(const unsigned char *)(p) << 8) \
	+ (*(const unsigned char *)((p) + 1)))

#define eb_uint4(p) ((*(const unsigned char *)(p) << 24) \
	+ (*(const unsigned char *)((p) + 1) << 16) \
	+ (*(const unsigned char *)((p) + 2) << 8) \
	+ (*(const unsigned char *)((p) + 3)))

#endif /* EB_UINT_FUNC */


/*
 * Function declarations.
 */
#ifdef __STDC__

/* io.h */
#ifdef EB_UINT_FUNC
unsigned eb_uint1(const char *);
unsigned eb_uint2(const char *);
unsigned eb_uint4(const char *);
#endif /* EB_UINT_FUNC */
unsigned eb_bcd2(const char *);
unsigned eb_bcd4(const char *);
unsigned eb_bcd6(const char *);
int eb_seek(EB_Book *, const EB_Position *);
int eb_tell(EB_Book *, EB_Position *);
ssize_t eb_read(EB_Book *, char *, size_t);

#else /* not __STDC__ */

/* io.h */
#ifdef EB_UINT_FUNC
unsigned eb_uint1();
unsigned eb_uint2();
unsigned eb_uint4();
#endif /* EB_UINT_FUNC */
unsigned eb_bcd2();
unsigned eb_bcd4();
unsigned eb_bcd6();
int eb_seek();
int eb_tell();
ssize_t eb_read();

#endif /* not __STDC__ */


#ifdef __cplusplus
}
#endif

#endif /* not EB_IO_H */
